# Pyguin
Nobody asked for it but it's getting made anyway, another static site generator written in Python.

# Installation instructions 
It's available on PyPi, so you should be able to simply 
```pip install pyguin```
and evoke ```pyguin``` in your terminal. 
# Documentation 
There are semi-useful help messages in the CLI tool as it is now, stand by for better documentation.